@@ -169,7 +169,7 @@ def __upsert_function(micro_batch_df: DataFrame, batch_id: int, db_name, table_n
 
 # TODO: ADICIONAR PARAMETRO DE PATH
 def write_table(df: DataFrame, checkpoint_location: str, db_name: str, table_name: str, spark=None, partition_columns=None, write_options: dict = None,
-                sort_fields: list = None, upsert_fields: list = None, output_path: str = None):
+                sort_fields: list = None, upsert_fields: list = None):
     if partition_columns is None:
         partition_columns = list()
     if sort_fields is None:
@@ -179,11 +179,9 @@ def write_table(df: DataFrame, checkpoint_location: str, db_name: str, table_nam
     if spark is None:
         spark = get_spark_session('upsert_data')
 
-    print(f'STREAM WILL WRITE TO: {output_path}')
     stream = df.writeStream.trigger(once=True) \
         .format('delta') \
         .option('checkpointLocation', checkpoint_location) \
-        .option('path', output_path) \
         .options(**write_options)
 
     # TODO: MODULARIZAR
@@ -279,10 +277,9 @@ def landing_to_bronze(data_input_path, data_type: str, data_pack_name, dataset_n
     df = process_dataframe(df, js_schema=js_schema)
     df = __rename_invalid_columns(df)
 
-    output_path = build_table_path(bucket_name=BRONZE_BUCKET, data_pack_name=data_pack_name, dataset_name=dataset_name)
     checkpoint_location = build_checkpoint_path(bucket_name=BRONZE_BUCKET, data_pack_name=data_pack_name, dataset_name=dataset_name)
     stream = write_table(df, checkpoint_location=checkpoint_location, db_name=BRONZE_DB_NAME, table_name=dataset_name, spark=spark,
-                         partition_columns=partition_columns, write_options=write_options, output_path=output_path)
+                         partition_columns=partition_columns, write_options=write_options)
 
     if profiling:
         stream.awaitTermination()
@@ -305,7 +302,7 @@ def landing_to_bronze_schema(data_input_path, data_type: str, data_pack_name, da
 
     checkpoint_location = build_checkpoint_path(bucket_name=BRONZE_BUCKET, data_pack_name=data_pack_name, dataset_name=dataset_name)
     stream = write_table(df, checkpoint_location=checkpoint_location, db_name=BRONZE_DB_NAME, table_name=dataset_name, spark=spark,
-                         partition_columns=partition_columns, write_options=write_options)
+                         partition_columns=partition_columns)
 
 
 def bronze_to_silver(input_table_name, data_pack_name, dataset_name, input_db_name=BRONZE_DB_NAME, partition_columns=None, spark=None,
@@ -316,15 +313,14 @@ def bronze_to_silver(input_table_name, data_pack_name, dataset_name, input_db_na
     if partition_columns is None:
         partition_columns = list()
     if reset_checkpoint:
-        reset_autoloader_checkpoint(bucket_name=SILVER_BUCKET, data_pack_name=data_pack_name, dataset_name=dataset_name)
+        reset_autoloader_checkpoint(bucket_name=SILVER_BUCKET, data_pack_name=data_pack_name, dataset_name=dataset_name, input_table_name=input_table_name)
 
     df = read_table(spark, db_name=input_db_name, table_name=input_table_name)
     df = apply_processing_function(df=df, func=processing_function, func_args=processing_function_args, func_kwargs=processing_function_kwargs)
 
-    output_path = build_table_path(bucket_name=SILVER_BUCKET, data_pack_name=data_pack_name, dataset_name=dataset_name)
     checkpoint_location = build_checkpoint_path(bucket_name=SILVER_BUCKET, data_pack_name=data_pack_name, dataset_name=dataset_name, input_table_name=input_table_name)
     stream = write_table(df, checkpoint_location=checkpoint_location, db_name=SILVER_DB_NAME, table_name=dataset_name, spark=spark,
-                         partition_columns=partition_columns, write_options=write_options, output_path=output_path)
+                         partition_columns=partition_columns, write_options=write_options)
 
     if profiling:
         stream.awaitTermination()
@@ -344,14 +340,13 @@ def silver_to_gold(input_table_name, data_pack_name, dataset_name, input_db_name
     if sort_fields is None:
         sort_fields = get_table_partitions(spark=spark, db_name=input_db_name, table_name=input_table_name)
     if reset_checkpoint:
-        reset_autoloader_checkpoint(bucket_name=GOLD_BUCKET, data_pack_name=data_pack_name, dataset_name=dataset_name)
+        reset_autoloader_checkpoint(bucket_name=GOLD_BUCKET, data_pack_name=data_pack_name, dataset_name=dataset_name, input_table_name=input_table_name)
 
     df = read_table(spark, db_name=input_db_name, table_name=input_table_name)
     df = apply_processing_function(df=df, func=processing_function, func_args=processing_function_args, func_kwargs=processing_function_kwargs)
 
-    output_path = build_table_path(bucket_name=GOLD_BUCKET, data_pack_name=data_pack_name, dataset_name=dataset_name)
     checkpoint_location = build_checkpoint_path(bucket_name=GOLD_BUCKET, data_pack_name=data_pack_name, dataset_name=dataset_name, input_table_name=input_table_name)
-    stream = write_table(df, checkpoint_location=checkpoint_location, db_name=GOLD_DB_NAME, table_name=dataset_name, spark=spark, output_path=output_path,
+    stream = write_table(df, checkpoint_location=checkpoint_location, db_name=GOLD_DB_NAME, table_name=dataset_name, spark=spark,
                          partition_columns=partition_columns, write_options=write_options, sort_fields=sort_fields, upsert_fields=upsert_fields)
 
     if profiling:
